@@ -271,7 +271,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 	if (priv->tag != NULL) {
 		APPEND_SEP
 		g_string_append (query_uri, "tag=");
-		g_string_append_uri_escaped (query_uri, priv->tag, NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, priv->tag, NULL, FALSE);
 	}
 
 	if (priv->bounding_box.north != priv->bounding_box.south && priv->bounding_box.east != priv->bounding_box.west) {
@@ -288,7 +288,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 	if (priv->location != NULL) {
 		APPEND_SEP
 		g_string_append (query_uri, "l=");
-		g_string_append_uri_escaped (query_uri, priv->location, NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, priv->location, NULL, FALSE);
 	}
 }
 
@@ -388,7 +388,7 @@ gdata_picasaweb_query_set_thumbnail_size (GDataPicasaWebQuery *self, const gchar
  *
  * Gets the #GDataPicasaWebQuery:image-size property.
  *
- * Return value: a comma-separated list of image sizes to retrieve, or %NULL
+ * Return value: the currently set desired image size for retrieval, or %NULL
  *
  * Since: 0.4.0
  **/
@@ -402,9 +402,11 @@ gdata_picasaweb_query_get_image_size (GDataPicasaWebQuery *self)
 /**
  * gdata_picasaweb_query_set_image_size:
  * @self: a #GDataPicasaWebQuery
- * @image_size: a comma-separated list of image sizes to retrieve, or %NULL
+ * @image_size: the desired size of the image to be retrieved, or %NULL
  *
  * Sets the #GDataPicasaWebQuery:image-size property to @image_size.
+ * Valid sizes are described here:
+ * http://code.google.com/apis/picasaweb/docs/2.0/reference.html#Parameters
  *
  * Set @image_size to %NULL to unset the property.
  *
