@@ -632,7 +632,8 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 		}
 
 		self->priv->media_group = group;
-	} else if (xmlStrcmp (node->name, (xmlChar*) "rating") == 0) {
+	} else if (node->ns != NULL && xmlStrcmp (node->ns->href, (xmlChar*) "http://schemas.google.com/g/2005") == 0 &&
+	           xmlStrcmp (node->name, (xmlChar*) "rating") == 0) {
 		/* gd:rating */
 		xmlChar *min, *max, *num_raters, *average;
 		guint num_raters_uint;
@@ -792,11 +793,8 @@ get_xml (GDataParsable *parsable, GString *xml_string)
 	/* media:group */
 	_gdata_parsable_get_xml (GDATA_PARSABLE (priv->media_group), xml_string, FALSE);
 
-	if (priv->location != NULL) {
-		gchar *location = g_markup_escape_text (priv->location, -1);
-		g_string_append_printf (xml_string, "<yt:location>%s</yt:location>", location);
-		g_free (location);
-	}
+	if (priv->location != NULL)
+		gdata_parser_string_append_escaped (xml_string, "<yt:location>", priv->location, "</yt:location>");
 
 	if (priv->recorded.tv_sec != 0 || priv->recorded.tv_usec != 0) {
 		gchar *recorded = gdata_parser_date_from_time_val (&(priv->recorded));
